@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by Georg Hennig                               *
+ *   Copyright (C) 2005-2013 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -673,12 +673,13 @@ int KomparatorCompareJob::comparePath( KFileItemExt *item1, KFileItemExt *item2
 KFileItemExt *KomparatorCompareJob::newerItem( KFileItemExt *item1, KFileItemExt *item2 )
 {
 	if ( isCanceled() ) return NULL;
+	if (!item1 || !item2 ) return NULL;
 
-	if ( item1->time( KFileItem::ModificationTime ).toTime_t() > item2->time( KFileItem::ModificationTime ).toTime_t() )
+	if ( item1->getKFileItemExtModificationTimeT() > item2->getKFileItemExtModificationTimeT() )
 	{
 		return item1; // bigger time means newer
 	}
-	else if ( item1->time( KFileItem::ModificationTime ).toTime_t() < item2->time( KFileItem::ModificationTime ).toTime_t() )
+	else if ( item1->getKFileItemExtModificationTimeT() < item2->getKFileItemExtModificationTimeT() )
 	{
 		return item2;
 	}
@@ -690,7 +691,7 @@ KFileItemExt *KomparatorCompareJob::newerItem( KFileItemExt *item1, KFileItemExt
 
 void KomparatorCompareJob::purgeTree( FileTree *tree )
 {
-	if ( tree == NULL ) return;
+	if ( !tree ) return;
 
 	if ( tree->left != NULL ) purgeTree( tree->left );
 
