@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by Georg Hennig                               *
+ *   Copyright (C) 2005-2013 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -28,6 +28,7 @@
 #include <QEvent>
 #include <QKeyEvent>
 #include <QFrame>
+#include <QMutex>
 
 #include <KDebug>
 #include <KDateTable>
@@ -187,24 +188,26 @@ void KomparatorFileFilter::init()
 	size_box->setLayout( size_box_layout );
 
 	size_box_layout->addWidget( new QLabel( i18n( "Size between" ), size_box ), 0, 0 );
-	m_min_size = new KIntSpinBox( 0/*lower*/, 9999/*upper*/, 1/*step*/, 0/*value*/, size_box/*parent*/, 10/*base*/ );
+	m_min_size = new KIntSpinBox( 0/*lower*/, 99999/*upper*/, 1/*step*/, 0/*value*/, size_box/*parent*/, 10/*base*/ );
 	size_box_layout->addWidget( m_min_size, 0, 1 );
 	m_min_size_combo = new QComboBox( size_box );
 	size_box_layout->addWidget( m_min_size_combo, 0, 2 );
 	m_min_size_combo->insertItem( 999, i18n( "Byte(s)" ) );
 	m_min_size_combo->insertItem( 999, i18n( "KB" ) );
 	m_min_size_combo->insertItem( 999, i18n( "MB" ) );
+	m_min_size_combo->insertItem( 999, i18n( "GB" ) );
 	QLabel *and_label = new QLabel( i18n( "and" ), size_box );
 	size_box_layout->addWidget( and_label, 1, 0 );
 	and_label->setAlignment( Qt::AlignRight | Qt::AlignVCenter );
-	m_max_size = new KIntSpinBox( 0/*lower*/, 9999/*upper*/, 1/*step*/, 9999/*value*/, size_box/*parent*/, 10/*base*/ );
+	m_max_size = new KIntSpinBox( 0/*lower*/, 99999/*upper*/, 1/*step*/, 99999/*value*/, size_box/*parent*/, 10/*base*/ );
 	size_box_layout->addWidget( m_max_size, 1, 1 );
 	m_max_size_combo = new QComboBox( size_box );
 	size_box_layout->addWidget( m_max_size_combo, 1, 2 );
 	m_max_size_combo->insertItem( 999, i18n( "Byte(s)" ) );
 	m_max_size_combo->insertItem( 999, i18n( "KB" ) );
 	m_max_size_combo->insertItem( 999, i18n( "MB" ) );
-	m_max_size_combo->setCurrentIndex( 2 );
+	m_max_size_combo->insertItem( 999, i18n( "GB" ) );
+	m_max_size_combo->setCurrentIndex( 3 );
 	connect( m_min_size, SIGNAL( valueChanged( int ) ), this, SLOT( slotEmitChanged() ) );
 	connect( m_min_size_combo, SIGNAL( activated( const QString & ) ), this, SLOT( slotEmitChanged( const QString & ) ) );
 	connect( m_max_size, SIGNAL( valueChanged( int ) ), this, SLOT( slotEmitChanged() ) );
@@ -217,11 +220,15 @@ void KomparatorFileFilter::init()
 
 	m_date_checkbox = new QCheckBox( i18n( "Modified or created" ), time_box );
 	time_box_layout->addWidget( m_date_checkbox );
-	m_date_combo = new KDateCombo( QDate::currentDate(), time_box );
+
+	static QMutex mutex;
+	QMutexLocker locker(&mutex);
+	QDate current_date = QDate::currentDate();
+	m_date_combo = new KDateCombo( current_date, time_box );
+	
 	time_box_layout->addWidget( m_date_combo );
 	m_date_combo->setEnabled( false );
 	connect( m_date_combo, SIGNAL( activated( const QString & ) ), this, SLOT( slotEmitChanged( const QString & ) ) );
-	connect( m_date_combo, SIGNAL( signalUpdated( const QString & ) ), this, SLOT( slotEmitChanged( const QString & ) ) );
 	connect( m_date_checkbox, SIGNAL( toggled( bool ) ), this, SLOT( slotConsiderDate( bool ) ) );
 
 	const QString clear_tt = i18n( "Reset all filters to default values" );
@@ -345,19 +352,19 @@ void KomparatorFileFilter::emitChanged()
 	if ( m_filter_type == DUPLICATES_TYPE )
 	{
 		emit( signalChanged( this, m_name_edit->text(), m_path_edit->text(), m_owner_edit->text(), m_group_edit->text(),
-			m_min_size->value() << (10*m_min_size_combo->currentIndex()), m_max_size->value() << (10*m_max_size_combo->currentIndex()),
+			(KIO::filesize_t) m_min_size->value() << (10*m_min_size_combo->currentIndex()), (KIO::filesize_t) m_max_size->value() << (10*m_max_size_combo->currentIndex()),
 			m_date_checkbox->isChecked(), date, m_duplicates_normal->isChecked(), m_duplicates_multiple->isChecked() ) );
 	}
 	else if ( m_filter_type == NEWER_TYPE )
 	{
 		emit( signalChanged( this, m_name_edit->text(), m_path_edit->text(), m_owner_edit->text(), m_group_edit->text(),
-			m_min_size->value() << (10*m_min_size_combo->currentIndex()), m_max_size->value() << (10*m_max_size_combo->currentIndex()),
+			(KIO::filesize_t) m_min_size->value() << (10*m_min_size_combo->currentIndex()), (KIO::filesize_t) m_max_size->value() << (10*m_max_size_combo->currentIndex()),
 			m_date_checkbox->isChecked(), date, m_newer_real->isChecked(), m_newer_equal->isChecked(), m_newer_same_time->isChecked() ) );
 	}
 	else
 	{
 		emit( signalChanged( this, m_name_edit->text(), m_path_edit->text(), m_owner_edit->text(), m_group_edit->text(),
-			m_min_size->value() << (10*m_min_size_combo->currentIndex()), m_max_size->value() << (10*m_max_size_combo->currentIndex()),
+			(KIO::filesize_t) m_min_size->value() << (10*m_min_size_combo->currentIndex()), (KIO::filesize_t) m_max_size->value() << (10*m_max_size_combo->currentIndex()),
 			m_date_checkbox->isChecked(), date ) );
 	}
 }
@@ -370,12 +377,15 @@ void KomparatorFileFilter::slotClear()
 	m_group_edit->setText( "" );
 
 	m_min_size->setValue( 0 );
-	m_max_size->setValue( 9999 );
+	m_max_size->setValue( 99999 );
 	m_min_size_combo->setCurrentIndex( 0 );
-	m_max_size_combo->setCurrentIndex( 2 );
+	m_max_size_combo->setCurrentIndex( 3 );
 
 	m_date_checkbox->setChecked( false );
-	m_date_combo->setDate( QDate::currentDate() );
+	static QMutex mutex;
+	QMutexLocker locker(&mutex);
+	QDate current_date = QDate::currentDate();
+	m_date_combo->setDate( current_date );
 
 	if ( m_newer_real ) m_newer_real->setChecked( true );
 	if ( m_newer_equal ) m_newer_equal->setChecked( true );
