@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by Georg Hennig                               *
+ *   Copyright (C) 2005-2013 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -22,6 +22,9 @@
 #include <QLabel>
 #include <QRadioButton>
 #include <QDate>
+#include <QMutex>
+
+#include <iostream>
 
 #include <QComboBox>
 #include <KConfig>
@@ -55,10 +58,15 @@ KomparatorPreset::KomparatorPreset( KomparatorWidget *_parent, KSharedConfigPtr
 	m_regex_containsnot = "";
 	m_size_selection = 0; // 0 = none, 1 = at least, 2 = at most, 3 = equal to.
 	m_size = 0; // spin box content
-	m_size_multiple = 1; // 0 = bytes, 1 = KB, 2 = MB
+	m_size_multiple = 1; // 0 = bytes, 1 = KB, 2 = MB, 3=GB
 	m_modified_or_created = 0; // 0 = any, 1 = between, 2 = during the last
+
+	static QMutex mutex;
+	QMutexLocker locker(&mutex);
 	m_date1 = QDate::currentDate();
 	m_date2 = QDate::currentDate();
+	QDate current_date = QDate::currentDate();
+
 	m_date3_num = 0;
 	m_modified_last = 0; // 0 = minutes, 1 = hours, 2 = days, 3 = months, 4 = years
 	m_ignore_empty = true;
@@ -85,52 +93,52 @@ KomparatorPreset::KomparatorPreset( KomparatorWidget *_parent, KSharedConfigPtr
 
 	// set correct default values now:
 	// 0 and 1: min size, min size unit
-	m_filter_int[2] = 9999; // duplicates1: 0..10
-	m_filter_int[3] = 2;
+	m_filter_int[2] = 99999; // duplicates1: 0..10
+	m_filter_int[3] = 3;
 	// 4: date check box
-	m_filter_int[5] = QDate::currentDate().year();
-	m_filter_int[6] = QDate::currentDate().month();
-	m_filter_int[7] = QDate::currentDate().day();
+	m_filter_int[5] = current_date.year();
+	m_filter_int[6] = current_date.month();
+	m_filter_int[7] = current_date.day();
 	m_filter_int[8] = 1;
 	m_filter_int[9] = 1;
 	m_filter_int[10] = 1;
 
-	m_filter_int[13] = 9999; // duplicates2: 11..19
-	m_filter_int[14] = 2;
-	m_filter_int[16] = QDate::currentDate().year();
-	m_filter_int[17] = QDate::currentDate().month();
-	m_filter_int[18] = QDate::currentDate().day();
+	m_filter_int[13] = 99999; // duplicates2: 11..19
+	m_filter_int[14] = 3;
+	m_filter_int[16] = current_date.year();
+	m_filter_int[17] = current_date.month();
+	m_filter_int[18] = current_date.day();
 	m_filter_int[19] = 1;
 
-	m_filter_int[22] = 9999; // missing1: 20..28
-	m_filter_int[23] = 2;
-	m_filter_int[25] = QDate::currentDate().year();
-	m_filter_int[26] = QDate::currentDate().month();
-	m_filter_int[27] = QDate::currentDate().day();
+	m_filter_int[22] = 99999; // missing1: 20..28
+	m_filter_int[23] = 3;
+	m_filter_int[25] = current_date.year();
+	m_filter_int[26] = current_date.month();
+	m_filter_int[27] = current_date.day();
 	m_filter_int[28] = 1;
 
-	m_filter_int[31] = 9999; // missing2: 29..37
-	m_filter_int[32] = 2;
-	m_filter_int[34] = QDate::currentDate().year();
-	m_filter_int[35] = QDate::currentDate().month();
-	m_filter_int[36] = QDate::currentDate().day();
+	m_filter_int[31] = 99999; // missing2: 29..37
+	m_filter_int[32] = 3;
+	m_filter_int[34] = current_date.year();
+	m_filter_int[35] = current_date.month();
+	m_filter_int[36] = current_date.day();
 	m_filter_int[37] = 1;
 
-	m_filter_int[40] = 9999; // newer1: 38..49
-	m_filter_int[41] = 2;
-	m_filter_int[43] = QDate::currentDate().year();
-	m_filter_int[44] = QDate::currentDate().month();
-	m_filter_int[45] = QDate::currentDate().day();
+	m_filter_int[40] = 99999; // newer1: 38..49
+	m_filter_int[41] = 3;
+	m_filter_int[43] = current_date.year();
+	m_filter_int[44] = current_date.month();
+	m_filter_int[45] = current_date.day();
 	m_filter_int[46] = 1;
 	m_filter_int[47] = 1;
 	m_filter_int[48] = 1;
 	m_filter_int[49] = 1;
 
-	m_filter_int[52] = 9999; // newer2: 50..61
-	m_filter_int[53] = 2;
-	m_filter_int[55] = QDate::currentDate().year();
-	m_filter_int[56] = QDate::currentDate().month();
-	m_filter_int[57] = QDate::currentDate().day();
+	m_filter_int[52] = 99999; // newer2: 50..61
+	m_filter_int[53] = 3;
+	m_filter_int[55] = current_date.year();
+	m_filter_int[56] = current_date.month();
+	m_filter_int[57] = current_date.day();
 	m_filter_int[58] = 1;
 	m_filter_int[59] = 1;
 	m_filter_int[60] = 1;
