@@ -1,5 +1,5 @@
 /***************************************************************************
- *   Copyright (C) 2005-2010 by Georg Hennig                               *
+ *   Copyright (C) 2005-2013 by Georg Hennig                               *
  *   Email: georg.hennig@web.de                                            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -267,13 +267,10 @@ QWidget *KompareDialog::createBasicInfos( QWidget *local_parent, KFileItemExt *i
 
 	entries_box_layout->addWidget( new KSqueezedTextLabel( url, entries_box ) );
 	QString size1_str = KIO::convertSize( item->size() );
-	if ( item->size() >= 1024 ) size1_str += " (" + KGlobal::locale()->formatNumber( item->size(), 0 ) + " B)";
+	if ( item->size() >= 1024 ) size1_str += " (" + QString( "%1" ).arg( item->size() ) + " B)";
 	entries_box_layout->addWidget( new QLabel( size1_str, entries_box ) );
-	QDateTime dt1;
-	dt1.setTime_t( item->time( KFileItem::ModificationTime ).toTime_t() );
-	entries_box_layout->addWidget( new QLabel( KGlobal::locale()->formatDateTime( dt1 ), entries_box ) );
-	dt1.setTime_t( item->time( KFileItem::AccessTime ).toTime_t() );
-	entries_box_layout->addWidget( new QLabel( KGlobal::locale()->formatDateTime( dt1 ), entries_box ) );
+	entries_box_layout->addWidget( new QLabel( item->getKFileItemExtModificationTimeString(), entries_box ) );
+	entries_box_layout->addWidget( new QLabel( item->getKFileItemExtAccessTimeString(), entries_box ) );
 	entries_box_layout->addWidget( new QLabel( item->user(), entries_box ) );
 	entries_box_layout->addWidget( new QLabel( item->group(), entries_box ) );
 	entries_box_layout->addWidget( new QLabel( item->permissionsString(), entries_box ) );
