@@ -20,18 +20,18 @@
 
 #include <stdlib.h>
 
-#include <QFileInfo>
-#include <QTextCodec>
-#include <QTextStream>
-#include <QList>
-#include <KDebug>
-#include <KFileItem>
-#include <KFileMetaInfo>
-#include <KApplication>
-#include <KMessageBox>
-#include <KLocale>
-#include <KStandardDirs>
-#include <KZip>
+#include <QtCore/QFileInfo>
+#include <QtCore/QTextCodec>
+#include <QtCore/QTextStream>
+#include <QtCore/QList>
+#include <kdebug.h>
+#include <kfileitem.h>
+#include <kfilemetainfo.h>
+#include <kapplication.h>
+#include <kmessagebox.h>
+#include <klocale.h>
+#include <kstandarddirs.h>
+#include <kzip.h>
 
 KQuery::KQuery(QObject *parent)
   : QObject(parent),
@@ -45,7 +45,7 @@ KQuery::KQuery(QObject *parent)
   processLocate = new KProcess(this);
   connect(processLocate,SIGNAL(readyReadStandardOutput()),this,SLOT(slotreadyReadStandardOutput()));
   connect(processLocate,SIGNAL(readyReadStandardError()),this,SLOT(slotreadyReadStandardError()));
-  connect(processLocate,SIGNAL(finished(int, QProcess::ExitStatus)),this,SLOT(slotendProcessLocate(int, QProcess::ExitStatus)));
+  connect(processLocate,SIGNAL(finished(int,QProcess::ExitStatus)),this,SLOT(slotendProcessLocate(int,QProcess::ExitStatus)));
 
   // Files with these mime types can be ignored, even if
   // findFormatByFileContent() in some cases may claim that
@@ -122,10 +122,10 @@ void KQuery::start()
     else
       job = KIO::listDir( m_url, KIO::HideProgressInfo );
 
-    connect(job, SIGNAL(entries(KIO::Job *, const KIO::UDSEntryList &)),
-        SLOT(slotListEntries(KIO::Job *, const KIO::UDSEntryList &)));
-    connect(job, SIGNAL(result(KJob *)), SLOT(slotResult(KJob *)));
-    connect(job, SIGNAL(canceled(KJob *)), SLOT(slotCanceled(KJob *)));
+    connect(job, SIGNAL(entries(KIO::Job*,KIO::UDSEntryList)),
+        SLOT(slotListEntries(KIO::Job*,KIO::UDSEntryList)));
+    connect(job, SIGNAL(result(KJob*)), SLOT(slotResult(KJob*)));
+    connect(job, SIGNAL(canceled(KJob*)), SLOT(slotCanceled(KJob*)));
   }
 }
 
@@ -432,6 +432,8 @@ void KQuery::processQuery( const KFileItem &file)
       QString str = stream->readLine();
       matchingLineNumber++;
 
+      //If the stream ended (readLine().isNull() is true) the file was read completely
+      //Do *not* use isEmpty() because that will exit if there is an empty line in the file
       if (str.isNull()) break;
       if(isZippedOfficeDocument)
         str.remove(xmlTags);
@@ -573,7 +575,7 @@ void KQuery::setShowHiddenFiles(bool showHidden)
 
 void KQuery::slotreadyReadStandardError()
 {
-  KMessageBox::error(NULL, QString::fromLocal8Bit(processLocate->readAllStandardOutput()), i18n("Error while using locate"));
+  KMessageBox::error(NULL, QString::fromLocal8Bit(processLocate->readAllStandardOutput()), i18nc("@title:window", "Error while using locate"));
 }
 
 void KQuery::slotreadyReadStandardOutput()
